@@ -50,5 +50,9 @@ class MicroblogConfig(ConfigParser):
                 config['shortener'] = self.get('global','shortener').strip()
             except NoOptionError:
                 config['shortener'] = 'tinyurl'
+
+            if config['service'] == 'wordpress':
+                config['xmlrpc_url'] = self.get(section, "xmlrpc_url").strip()
+
             self._configs.append(config)
         return self._configs
