@@ -23,6 +23,7 @@ import time
 import re
 import logging
 log = logging.getLogger(__name__)
+import pyblog
 
 class Microblog(object):
     def strip_tags(self,value):
@@ -68,6 +69,17 @@ class Microblog(object):
                 #lets try in the next time
                 return
 
+class WordpressAPI(object):
+    def __init__(self,username = None, password = None, xmlrpc_url = None):
+        self.blog = pyblog.WordPress(xmlrpc_url, username, password)
+
+    def PostUpdate(self,post):
+        self.blog.new_post(post)
+        status = type('',(),{})() 
+        status.text = post['title']
+        return status
+
+
 class IdenticaAPI(Api):
 
     _API_REALM = 'Laconica API'
@@ -132,12 +144,45 @@ class Identica(Microblog):
         self.rss = readrss.parse(url,self.__class__.__name__.lower())
         self.shortener = services[shortener]()
 
+class Wordpress(Microblog):
+    def __init__(self,  url, username, passwd, mode='title', items = 5, shortener='tinyurl',xmlrpc_url=None):
+        self.mode = mode
+        self.url = url
+        self.items = items
+        self.username = username
+        self.passwd = passwd
+        self.api = WordpressAPI(username=self.username, password=self.passwd, xmlrpc_url= xmlrpc_url)
+        self.rss = readrss.parse(url,self.__class__.__name__.lower())
+        self.shortener = services[shortener]()
+
+    def postIt(self, items):
+        oldItems = pItems=0
+        for it in list(items):
+            post={}
+            post['title'] = it['title']
+            try:
+                post['description'] = it.content[0].value
+            except:
+                post['description'] = it.summary
+            post['description'] += '<p><a href="' + it['links'][-1]['href'] + '">Original</a></p>'
+            try:
+                status = self.api.PostUpdate(post)
+                self.rss.updateLastRead(it)
+                log.info(status.text + " posted on " + self.__class__.__name__.lower())
+                time.sleep(5)
+
+            except (BadStatusLine, HTTPError):
+                #lets try in the next time
+                return
+
 class service(object):
     def __init__(self,**kwargs):
         if kwargs['service'] == 'twitter':
             self.micro = Twitter(kwargs['url'],kwargs['username'],kwargs['password'],kwargs['mode'],kwargs['items'],kwargs['shortener'])
         elif kwargs['service'] == 'identica':
             self.micro = Identica(kwargs['url'],kwargs['username'],kwargs['password'],kwargs['mode'],kwargs['items'],kwargs['shortener'])
+        elif kwargs['service'] == 'wordpress':
+            self.micro = Wordpress(kwargs['url'],kwargs['username'],kwargs['password'],kwargs['mode'],kwargs['items'],kwargs['shortener'], kwargs['xmlrpc_url'])
 
     def get(self):
         return self.micro
